Code Updates - Nautobot Documentation

Skip to content

# App Code Updates for Nautobot v2

## Update Code Import Locations

Most changes in code location arise from the merging of the `nautobot.utilities` module into the `nautobot.core` module. Note that in most cases, the recommended approach for Jobs and Apps is to import from `nautobot.apps` rather than `nautobot.core` (see below).

Full table of code location changes

Old Module | Class/Function(s) | New Module
--- | --- | ---
nautobot.core.api.utils | TreeModelSerializerMixin | nautobot.core.api.serializers
nautobot.core.fields | (all) | nautobot.core.models.fields
nautobot.core.forms | SearchForm | nautobot.core.forms.search
nautobot.core.utilities | (all) | nautobot.core.views.utils
nautobot.dcim.fields | MACAddressCharField | nautobot.core.models.fields
nautobot.dcim.forms | MACAddressField | nautobot.core.forms
nautobot.extras.api.customfields | CustomFieldModelSerializerMixin | nautobot.core.api.serializers
nautobot.extras.api.relationships | RelationshipModelSerializerMixin | nautobot.core.api.serializers
nautobot.extras.api.serializers | NautobotModelSerializer | nautobot.core.api.serializers
nautobot.extras.api.serializers | NotesSerializerMixin | nautobot.core.api.serializers
nautobot.extras.api.serializers | TaggedModelSerializerMixin | nautobot.extras.api.mixins
nautobot.extras.utils | is_taggable | nautobot.core.models.utils
nautobot.utilities.api | (all) | nautobot.core.api.utils
nautobot.utilities.apps | (all) | nautobot.core.apps
nautobot.utilities.checks | (all) | nautobot.core.checks
nautobot.utilities.choices | (all) | nautobot.core.choices
nautobot.utilities.config | (all) | nautobot.core.utils.config
nautobot.utilities.constants | (all) | nautobot.core.constants
nautobot.utilities.deprecation | (all) | nautobot.core.utils.deprecation
nautobot.utilities.error_handlers | (all) | nautobot.core.views.utils
nautobot.utilities.exceptions | (all) | nautobot.core.exceptions
nautobot.utilities.factory | (all) | nautobot.core.factory
nautobot.utilities.fields | (all) | nautobot.core.models.fields
nautobot.utilities.filters | (all) | nautobot.core.filters
nautobot.utilities.forms | (all) | nautobot.core.forms
nautobot.utilities.git | (all) | nautobot.core.utils.git
nautobot.utilities.logging | (all) | nautobot.core.utils.logging
nautobot.utilities.management | (all) | nautobot.core.management
nautobot.utilities.ordering | (all) | nautobot.core.models.ordering
nautobot.utilities.paginator | (all) | nautobot.core.views.paginator
nautobot.utilities.permissions | (all) | nautobot.core.utils.permissions
nautobot.utilities.query_functions | (all) | nautobot.core.models.query_functions
nautobot.utilities.querysets | (all) | nautobot.core.models.querysets
nautobot.utilities.tables | (all) | nautobot.core.tables
nautobot.utilities.tasks | (all) | nautobot.core.tasks
nautobot.utilities.templatetags | (all) | nautobot.core.templatetags
nautobot.utilities.testing | (all) | nautobot.core.testing
nautobot.utilities.tree_queries | (all) | nautobot.core.models.tree_queries
nautobot.utilities.utils | array_to_string | nautobot.core.models.utils
nautobot.utilities.utils | convert_querydict_to_factory_formset_acceptable_querydict | nautobot.core.utils.requests
nautobot.utilities.utils | count_related | nautobot.core.models.querysets
nautobot.utilities.utils | csv_format | nautobot.core.views.utils
nautobot.utilities.utils | deepmerge | nautobot.core.utils.data
nautobot.utilities.utils | dict_to_filter_params | nautobot.core.api.utils
nautobot.utilities.utils | dynamic_import | nautobot.core.api.utils
nautobot.utilities.utils | ensure_content_type_and_field_name_in_query_params | nautobot.core.utils.requests
nautobot.utilities.utils | flatten_dict | nautobot.core.utils.data
nautobot.utilities.utils | flatten_iterable | nautobot.core.utils.data
nautobot.utilities.utils | foreground_color | nautobot.core.utils.color
nautobot.utilities.utils | get_all_lookup_expr_for_field | nautobot.core.utils.filtering
nautobot.utilities.utils | get_api_version_serializer | nautobot.core.api.utils
nautobot.utilities.utils | get_changes_for_model | nautobot.core.utils.lookup
nautobot.utilities.utils | get_filterset_field | nautobot.core.utils.filtering
nautobot.utilities.utils | get_filterset_for_model | nautobot.core.utils.lookup
nautobot.utilities.utils | get_filterable_params_from_filter_params | nautobot.core.utils.requests
nautobot.utilities.utils | get_form_for_model | nautobot.core.utils.lookup
nautobot.utilities.utils | get_model_from_name | nautobot.core.utils.lookup
nautobot.utilities.utils | get_related_class_for_model | nautobot.core.utils.lookup
nautobot.utilities.utils | get_route_for_model | nautobot.core.utils.lookup
nautobot.utilities.utils | get_table_for_model | nautobot.core.utils.lookup
nautobot.utilities.utils | hex_to_rgb | nautobot.core.utils.color
nautobot.utilities.utils | is_taggable | nautobot.core.models.utils
nautobot.utilities.utils | is_uuid | nautobot.core.utils.data
nautobot.utilities.utils | lighten_color | nautobot.core.utils.color
nautobot.utilities.utils | normalize_querydict | nautobot.core.utils.requests
nautobot.utilities.utils | prepare_cloned_fields | nautobot.core.views.utils
nautobot.utilities.utils | pretty_print_query | nautobot.core.models.utils
nautobot.utilities.utils | render_jinja2 | nautobot.core.utils.data
nautobot.utilities.utils | rgb_to_hex | nautobot.core.utils.color
nautobot.utilities.utils | SerializerForAPIVersions | nautobot.core.api.utils
nautobot.utilities.utils | serialize_object | nautobot.core.models.utils
nautobot.utilities.utils | serialize_object_v2 | nautobot.core.models.utils
nautobot.utilities.utils | shallow_compare_dict | nautobot.core.utils.data
nautobot.utilities.utils | slugify_dots_to_dashes | nautobot.core.models.fields
nautobot.utilities.utils | slugify_dashes_to_underscores | nautobot.core.models.fields
nautobot.utilities.utils | to_meters | nautobot.core.utils.data
nautobot.utilities.utils | UtilizationData | nautobot.core.utils.data
nautobot.utilities.utils | versioned_serializer_selector | nautobot.core.api.utils
nautobot.utilities.validators | (all) | nautobot.core.models.validators
nautobot.utilities.views | (all) | nautobot.core.views.mixins

Other than models, most other imports from Nautobot should be imported from `nautobot.apps.*` as described here.

Full table of `nautobot.apps` code locations

Nautobot Location | Public Interface
--- | ---
nautobot.core.signals.nautobot_database_ready | nautobot.apps.nautobot_database_ready
nautobot.core.settings_funcs.ConstanceConfigItem | nautobot.apps.ConstanceConfigItem
nautobot.extras.plugins.NautobotAppConfig | nautobot.apps.NautobotAppConfig
nautobot.core.admin.NautobotModelAdmin | nautobot.apps.admin.NautobotModelAdmin
nautobot.core.api.BaseModelSerializer | nautobot.apps.api.BaseModelSerializer
nautobot.core.api.CustomFieldModelSerializerMixin | nautobot.apps.api.CustomFieldModelSerializerMixin
nautobot.core.api.NautobotModelSerializer | nautobot.apps.api.NautobotModelSerializer
nautobot.core.api.NotesSerializerMixin | nautobot.apps.api.NotesSerializerMixin
nautobot.core.api.RelationshipModelSerializerMixin | nautobot.apps.api.RelationshipModelSerializerMixin
nautobot.core.api.ValidatedModelSerializer | nautobot.apps.api.ValidatedModelSerializer
nautobot.core.api.WritableNestedSerializer | nautobot.apps.api.WritableNestedSerializer
nautobot.core.api.fields.ChoiceField | nautobot.apps.api.ChoiceField
nautobot.core.api.fields.ContentTypeField | nautobot.apps.api.ContentTypeField
nautobot.core.api.fields.NautobotHyperlinkedRelatedField | nautobot.apps.api.NautobotHyperlinkedRelatedField
nautobot.core.api.fields.ObjectTypeField | nautobot.apps.api.ObjectTypeField
nautobot.core.api.fields.SerializedPKRelatedField | nautobot.apps.api.SerializedPKRelatedField
nautobot.core.api.fields.TimeZoneSerializerField | nautobot.apps.api.TimeZoneSerializerField
nautobot.core.api.mixins.WritableSerializerMixin | nautobot.apps.api.WritableSerializerMixin
nautobot.core.api.parsers.NautobotCSVParser | nautobot.apps.api.NautobotCSVParser
nautobot.core.api.routers.OrderedDefaultRouter | nautobot.apps.api.OrderedDefaultRouter
nautobot.core.api.schema.NautobotAutoSchema | nautobot.apps.api.NautobotAutoSchema
nautobot.core.api.serializers.OptInFieldsMixin | nautobot.apps.api.OptInFieldsMixin
nautobot.core.api.serializers.TreeModelSerializerMixin | nautobot.apps.api.TreeModelSerializerMixin
nautobot.core.api.utils.dict_to_filter_params | nautobot.apps.api.dict_to_filter_params
nautobot.core.api.utils.dynamic_import | nautobot.apps.api.dynamic_import
nautobot.core.api.utils.get_api_version_serializer | nautobot.apps.api.get_api_version_serializer
nautobot.core.api.utils.get_serializer_for_model | nautobot.apps.api.get_serializer_for_model
nautobot.core.api.utils.get_view_name | nautobot.apps.api.get_view_name
nautobot.core.api.utils.is_api_request | nautobot.apps.api.is_api_request
nautobot.core.api.utils.rest_api_server_error | nautobot.apps.api.rest_api_server_error
nautobot.core.api.utils.versioned_serializer_selector | nautobot.apps.api.versioned_serializer_selector
nautobot.core.api.views.APIRootView | nautobot.apps.api.APIRootView
nautobot.core.api.views.BulkDestroyModelMixin | nautobot.apps.api.BulkUpdateModelMixin
nautobot.core.api.views.BulkUpdateModelMixin | nautobot.apps.api.BulkDestroyModelMixin
nautobot.core.api.views.ModelViewSet | nautobot.apps.api.ModelViewSet
nautobot.core.api.views.ModelViewSetMixin | nautobot.apps.api.ModelViewSetMixin
nautobot.core.api.views.ReadOnlyModelViewSet | nautobot.apps.api.ReadOnlyModelViewSet
nautobot.extras.api.fields.MultipleChoiceJSONField | nautobot.apps.api.MultipleChoiceJSONField
nautobot.extras.api.mixins.TaggedModelSerializerMixin | nautobot.apps.api.TaggedModelSerializerMixin
nautobot.extras.api.views.CustomFieldModelViewSet | nautobot.apps.api.CustomFieldModelViewSet
nautobot.extras.api.views.NautobotModelViewSet | nautobot.apps.api.NautobotModelViewSet
nautobot.extras.api.views.NotesViewSetMixin | nautobot.apps.api.NotesViewSetMixin
nautobot.extras.context_managers.change_logging | nautobot.apps.change_logging.change_logging
nautobot.extras.context_managers.ChangeContext | nautobot.apps.change_logging.ChangeContext
nautobot.extras.context_managers.JobChangeContext | nautobot.apps.change_logging.JobChangeContext
nautobot.extras.context_managers.JobHookChangeContext | nautobot.apps.change_logging.JobHookChangeContext
nautobot.extras.context_managers.ORMChangeContext | nautobot.apps.change_logging.ORMChangeContext
nautobot.extras.context_managers.web_request_context | nautobot.apps.change_logging.web_request_context
nautobot.extras.context_managers.WebChangeContext | nautobot.apps.change_logging.WebChangeContext
nautobot.circuits.choices.CircuitTerminationSideChoices | nautobot.apps.choices.CircuitTerminationSideChoices
nautobot.core.choices.ButtonActionColorChoices | nautobot.apps.choices.ButtonActionColorChoices
nautobot.core.choices.ButtonActionIconChoices | nautobot.apps.choices.ButtonActionIconChoices
nautobot.core.choices.ChoiceSet | nautobot.apps.choices.ChoiceSet
nautobot.core.choices.ColorChoices | nautobot.apps.choices.ColorChoices
nautobot.core.choices.unpack_grouped_choices | nautobot.apps.choices.unpack_grouped_choices
nautobot.dcim.choices.CableLengthUnitChoices | nautobot.apps.choices.CableLengthUnitChoices
nautobot.dcim.choices.CableTypeChoices | nautobot.apps.choices.CableTypeChoices
nautobot.dcim.choices.ConsolePortTypeChoices | nautobot.apps.choices.ConsolePortTypeChoices
nautobot.dcim.choices.DeviceFaceChoices | nautobot.apps.choices.DeviceFaceChoices
nautobot.dcim.choices.DeviceRedundancyGroupFailoverStrategyChoices | nautobot.apps.choices.DeviceRedundancyGroupFailoverStrategyChoices
nautobot.dcim.choices.InterfaceModeChoices | nautobot.apps.choices.InterfaceModeChoices
nautobot.dcim.choices.InterfaceRedundancyGroupProtocolChoices | nautobot.apps.choices.InterfaceRedundancyGroupProtocolChoices
nautobot.dcim.choices.InterfaceTypeChoices | nautobot.apps.choices.InterfaceTypeChoices
nautobot.dcim.choices.PortTypeChoices | nautobot.apps.choices.PortTypeChoices
nautobot.dcim.choices.PowerFeedPhaseChoices | nautobot.apps.choices.PowerFeedPhaseChoices
nautobot.dcim.choices.PowerFeedSupplyChoices | nautobot.apps.choices.PowerFeedSupplyChoices
nautobot.dcim.choices.PowerFeedTypeChoices | nautobot.apps.choices.PowerFeedTypeChoices
nautobot.dcim.choices.PowerOutletFeedLegChoices | nautobot.apps.choices.PowerOutletFeedLegChoices
nautobot.dcim.choices.PowerOutletTypeChoices | nautobot.apps.choices.PowerOutletTypeChoices
nautobot.dcim.choices.PowerPortTypeChoices | nautobot.apps.choices.PowerPortTypeChoices
nautobot.dcim.choices.RackDimensionUnitChoices | nautobot.apps.choices.RackDimensionUnitChoices
nautobot.dcim.choices.RackElevationDetailRenderChoices | nautobot.apps.choices.RackElevationDetailRenderChoices
nautobot.dcim.choices.RackTypeChoices | nautobot.apps.choices.RackTypeChoices
nautobot.dcim.choices.RackWidthChoices | nautobot.apps.choices.RackWidthChoices
nautobot.dcim.choices.SubdeviceRoleChoices | nautobot.apps.choices.SubdeviceRoleChoices
nautobot.extras.choices.BannerClassChoices | nautobot.apps.choices.BannerClassChoices
nautobot.extras.choices.ButtonClassChoices | nautobot.apps.choices.ButtonClassChoices
nautobot.extras.choices.CustomFieldFilterLogicChoices | nautobot.apps.choices.CustomFieldFilterLogicChoices
nautobot.extras.choices.CustomFieldTypeChoices | nautobot.apps.choices.CustomFieldTypeChoices
nautobot.extras.choices.CustomLinkButtonClassChoices | nautobot.apps.choices.CustomLinkButtonClassChoices
nautobot.extras.choices.DynamicGroupOperatorChoices | nautobot.apps.choices.DynamicGroupOperatorChoices
nautobot.extras.choices.JobExecutionType | nautobot.apps.choices.JobExecutionType
nautobot.extras.choices.JobResultStatusChoices | nautobot.apps.choices.JobResultStatusChoices
nautobot.extras.choices.LogLevelChoices | nautobot.apps.choices.LogLevelChoices
nautobot.extras.choices.ObjectChangeActionChoices | nautobot.apps.choices.ObjectChangeActionChoices
nautobot.extras.choices.ObjectChangeEventContextChoices | nautobot.apps.choices.ObjectChangeEventContextChoices
nautobot.extras.choices.RelationshipRequiredSideChoices | nautobot.apps.choices.RelationshipRequiredSideChoices
nautobot.extras.choices.RelationshipSideChoices | nautobot.apps.choices.RelationshipSideChoices
nautobot.extras.choices.RelationshipTypeChoices | nautobot.apps.choices.RelationshipTypeChoices
nautobot.extras.choices.SecretsGroupAccessTypeChoices | nautobot.apps.choices.SecretsGroupAccessTypeChoices
nautobot.extras.choices.SecretsGroupSecretTypeChoices | nautobot.apps.choices.SecretsGroupSecretTypeChoices
nautobot.extras.choices.WebhookHttpMethodChoices | nautobot.apps.choices.WebhookHttpMethodChoices
nautobot.ipam.choices.IPAddressRoleChoices | nautobot.apps.choices.IPAddressRoleChoices
nautobot.ipam.choices.IPAddressTypeChoices | nautobot.apps.choices.IPAddressTypeChoices
nautobot.ipam.choices.IPAddressVersionChoices | nautobot.apps.choices.IPAddressVersionChoices
nautobot.ipam.choices.PrefixTypeChoices | nautobot.apps.choices.PrefixTypeChoices
nautobot.ipam.choices.ServiceProtocolChoices | nautobot.apps.choices.ServiceProtocolChoices
nautobot.extras.datasources.get_repo_access_url | nautobot.apps.datasources.get_repo_access_url
nautobot.extras.registry.DatasourceContent | nautobot.apps.datasources.DatasourceContent
nautobot.core.api.exceptions.SerializerNotFound | nautobot.apps.exceptions.SerializerNotFound
nautobot.core.api.exceptions.ServiceUnavailable | nautobot.apps.exceptions.ServiceUnavailable
nautobot.core.exceptions.AbortTransaction | nautobot.apps.exceptions.AbortTransaction
nautobot.core.exceptions.CeleryWorkerNotRunningException | nautobot.apps.exceptions.CeleryWorkerNotRunningException
nautobot.core.exceptions.FilterSetFieldNotFound | nautobot.apps.exceptions.FilterSetFieldNotFound
nautobot.core.runner.importer.ConfigurationError | nautobot.apps.exceptions.ConfigurationError
nautobot.extras.secrets.exceptions.SecretError | nautobot.apps.exceptions.SecretError
nautobot.extras.secrets.exceptions.SecretParametersError | nautobot.apps.exceptions.SecretParametersError
nautobot.extras.secrets.exceptions.SecretProviderError | nautobot.apps.exceptions.SecretProviderError
nautobot.extras.secrets.exceptions.SecretValueNotFoundError | nautobot.apps.exceptions.SecretValueNotFoundError
nautobot.core.factory.BaseModelFactory | nautobot.apps.factory.BaseModelFactory
nautobot.core.factory.get_random_instances | nautobot.apps.factory.get_random_instances
nautobot.core.factory.NautobotBoolIterator | nautobot.apps.factory.NautobotBoolIterator
nautobot.core.factory.NautobotFakerProvider | nautobot.apps.factory.NautobotFakerProvider
nautobot.core.factory.OrganizationalModelFactory | nautobot.apps.factory.OrganizationalModelFactory
nautobot.core.factory.PrimaryModelFactory | nautobot.apps.factory.PrimaryModelFactory
nautobot.core.factory.random_instance | nautobot.apps.factory.random_instance
nautobot.core.factory.UniqueFaker | nautobot.apps.factory.UniqueFaker
nautobot.core.filters.BaseFilterSet | nautobot.apps.filters.BaseFilterSet
nautobot.core.filters.ContentTypeChoiceFilter | nautobot.apps.filters.ContentTypeChoiceFilter
nautobot.core.filters.ContentTypeFilter | nautobot.apps.filters.ContentTypeFilter
nautobot.core.filters.ContentTypeFilterMixin | nautobot.apps.filters.ContentTypeFilterMixin
nautobot.core.filters.ContentTypeMultipleChoiceFilter | nautobot.apps.filters.ContentTypeMultipleChoiceFilter
nautobot.core.filters.MACAddressFilter | nautobot.apps.filters.MACAddressFilter
nautobot.core.filters.MappedPredicatesFilterMixin | nautobot.apps.filters.MappedPredicatesFilterMixin
nautobot.core.filters.multivalue_field_factory | nautobot.apps.filters.multivalue_field_factory
nautobot.core.filters.MultiValueBigNumberFilter | nautobot.apps.filters.MultiValueBigNumberFilter
nautobot.core.filters.MultiValueCharFilter | nautobot.apps.filters.MultiValueCharFilter
nautobot.core.filters.MultiValueDateFilter | nautobot.apps.filters.MultiValueDateFilter
nautobot.core.filters.MultiValueDateTimeFilter | nautobot.apps.filters.MultiValueDateTimeFilter
nautobot.core.filters.MultiValueDecimalFilter | nautobot.apps.filters.MultiValueDecimalFilter
nautobot.core.filters.MultiValueFloatFilter | nautobot.apps.filters.MultiValueFloatFilter
nautobot.core.filters.MultiValueMACAddressFilter | nautobot.apps.filters.MultiValueMACAddressFilter
nautobot.core.filters.MultiValueNumberFilter | nautobot.apps.filters.MultiValueNumberFilter
nautobot.core.filters.MultiValueTimeFilter | nautobot.apps.filters.MultiValueTimeFilter
nautobot.core.filters.MultiValueUUIDFilter | nautobot.apps.filters.MultiValueUUIDFilter
nautobot.core.filters.NameSearchFilterSet | nautobot.apps.filters.NameSearchFilterSet
nautobot.core.filters.NaturalKeyOrPKMultipleChoiceFilter | nautobot.apps.filters.NaturalKeyOrPKMultipleChoiceFilter
nautobot.core.filters.NumericArrayFilter | nautobot.apps.filters.NumericArrayFilter
nautobot.core.filters.RelatedMembershipBooleanFilter | nautobot.apps.filters.RelatedMembershipBooleanFilter
nautobot.core.filters.SearchFilter | nautobot.apps.filters.SearchFilter
nautobot.core.filters.TagFilter | nautobot.apps.filters.TagFilter
nautobot.core.filters.TreeNodeMultipleChoiceFilter | nautobot.apps.filters.TreeNodeMultipleChoiceFilter
nautobot.extras.filters.CreatedUpdatedModelFilterSetMixin | nautobot.apps.filters.CreatedUpdatedModelFilterSetMixin
nautobot.extras.filters.CustomFieldModelFilterSetMixin | nautobot.apps.filters.CustomFieldModelFilterSetMixin
nautobot.extras.filters.NautobotFilterSet | nautobot.apps.filters.NautobotFilterSet
nautobot.extras.filters.RelationshipModelFilterSetMixin | nautobot.apps.filters.RelationshipModelFilterSetMixin
nautobot.extras.filters.StatusModelFilterSetMixin | nautobot.apps.filters.StatusModelFilterSetMixin
nautobot.extras.filters.mixins.ConfigContextRoleFilter | nautobot.apps.filters.ConfigContextRoleFilter
nautobot.extras.filters.mixins.LocalContextModelFilterSetMixin | nautobot.apps.filters.LocalContextModelFilterSetMixin
nautobot.extras.filters.mixins.RelationshipFilter | nautobot.apps.filters.RelationshipFilter
nautobot.extras.filters.mixins.RoleFilter | nautobot.apps.filters.RoleFilter
nautobot.extras.filters.mixins.RoleModelFilterSetMixin | nautobot.apps.filters.RoleModelFilterSetMixin
nautobot.extras.filters.mixins.StatusFilter | nautobot.apps.filters.StatusFilter
nautobot.extras.plugins.FilterExtension | nautobot.apps.filters.FilterExtension
nautobot.tenancy.filters.TenancyModelFilterSetMixin | nautobot.apps.filters.TenancyModelFilterSetMixin
nautobot.core.forms.add_blank_choice | nautobot.apps.forms.add_blank_choice
nautobot.core.forms.AddressFieldMixin | nautobot.apps.forms.AddressFieldMixin
nautobot.core.forms.BootstrapMixin | nautobot.apps.forms.BootstrapMixin
nautobot.core.forms.BulkEditForm | nautobot.apps.forms.BulkEditForm
nautobot.core.forms.BulkRenameForm | nautobot.apps.forms.BulkRenameForm
nautobot.core.forms.ConfirmationForm | nautobot.apps.forms.ConfirmationForm
nautobot.core.forms.CSVModelForm | nautobot.apps.forms.CSVModelForm
nautobot.core.forms.DynamicFilterForm | nautobot.apps.forms.DynamicFilterForm
nautobot.core.forms.ImportForm | nautobot.apps.forms.ImportForm
nautobot.core.forms.PrefixFieldMixin | nautobot.apps.forms.PrefixFieldMixin
nautobot.core.forms.ReturnURLForm | nautobot.apps.forms.ReturnURLForm
nautobot.core.forms.TableConfigForm | nautobot.apps.forms.TableConfigForm
nautobot.core.forms.fields.CommentField | nautobot.apps.forms.CommentField
nautobot.core.forms.fields.CSVChoiceField | nautobot.apps.forms.CSVChoiceField
nautobot.core.forms.fields.CSVContentTypeField | nautobot.apps.forms.CSVContentTypeField
nautobot.core.forms.fields.CSVDataField | nautobot.apps.forms.CSVDataField
nautobot.core.forms.fields.CSVFileField | nautobot.apps.forms.CSVFileField
nautobot.core.forms.fields.CSVModelChoiceField | nautobot.apps.forms.CSVModelChoiceField
nautobot.core.forms.fields.CSVMultipleChoiceField | nautobot.apps.forms.CSVMultipleChoiceField
nautobot.core.forms.fields.CSVMultipleContentTypeField | nautobot.apps.forms.CSVMultipleContentTypeField
nautobot.core.forms.fields.DynamicModelChoiceField | nautobot.apps.forms.DynamicModelChoiceField
nautobot.core.forms.fields.DynamicModelChoiceMixin | nautobot.apps.forms.DynamicModelChoiceMixin
nautobot.core.forms.fields.DynamicModelMultipleChoiceField | nautobot.apps.forms.DynamicModelMultipleChoiceField
nautobot.core.forms.fields.ExpandableIPAddressField | nautobot.apps.forms.ExpandableIPAddressField
nautobot.core.forms.fields.ExpandableNameField | nautobot.apps.forms.ExpandableNameField
nautobot.core.forms.fields.JSONArrayFormField | nautobot.apps.forms.JSONArrayFormField
nautobot.core.forms.fields.JSONField | nautobot.apps.forms.JSONField
nautobot.core.forms.fields.LaxURLField | nautobot.apps.forms.LaxURLField
nautobot.core.forms.fields.MACAddressField | nautobot.apps.forms.MACAddressField
nautobot.core.forms.fields.MultiMatchModelMultipleChoiceField | nautobot.apps.forms.MultiMatchModelMultipleChoiceField
nautobot.core.forms.fields.MultipleContentTypeField | nautobot.apps.forms.MultipleContentTypeField
nautobot.core.forms.fields.MultiValueCharField | nautobot.apps.forms.MultiValueCharField
nautobot.core.forms.fields.NullableDateField | nautobot.apps.forms.NullableDateField
nautobot.core.forms.fields.NumericArrayField | nautobot.apps.forms.NumericArrayField
nautobot.core.forms.fields.SlugField | nautobot.apps.forms.SlugField
nautobot.core.forms.fields.TagFilterField | nautobot.apps.forms.TagFilterField
nautobot.core.forms.forms.dynamic_formset_factory | nautobot.apps.forms.dynamic_formset_factory
nautobot.core.forms.utils.add_field_to_filter_form_class, | nautobot.apps.forms.add_field_to_filter_form_class,
nautobot.core.forms.utils.expand_alphanumeric_pattern | nautobot.apps.forms.expand_alphanumeric_pattern
nautobot.core.forms.utils.expand_ipaddress_pattern | nautobot.apps.forms.expand_ipaddress_pattern
nautobot.core.forms.utils.form_from_model | nautobot.apps.forms.form_from_model
nautobot.core.forms.utils.parse_alphanumeric_range | nautobot.apps.forms.parse_alphanumeric_range
nautobot.core.forms.utils.parse_numeric_range | nautobot.apps.forms.parse_numeric_range
nautobot.core.forms.utils.restrict_form_fields | nautobot.apps.forms.restrict_form_fields
nautobot.core.forms.widgets.APISelect | nautobot.apps.forms.APISelect
nautobot.core.forms.widgets.APISelectMultiple | nautobot.apps.forms.APISelectMultiple
nautobot.core.forms.widgets.BulkEditNullBooleanSelect | nautobot.apps.forms.BulkEditNullBooleanSelect
nautobot.core.forms.widgets.ColorSelect | nautobot.apps.forms.ColorSelect
nautobot.core.forms.widgets.ContentTypeSelect | nautobot.apps.forms.ContentTypeSelect
nautobot.core.forms.widgets.DatePicker | nautobot.apps.forms.DatePicker
nautobot.core.forms.widgets.DateTimePicker | nautobot.apps.forms.DateTimePicker
nautobot.core.forms.widgets.MultiValueCharInput | nautobot.apps.forms.MultiValueCharInput
nautobot.core.forms.widgets.SelectWithDisabled | nautobot.apps.forms.SelectWithDisabled
nautobot.core.forms.widgets.SelectWithPK | nautobot.apps.forms.SelectWithPK
nautobot.core.forms.widgets.SlugWidget | nautobot.apps.forms.SlugWidget
nautobot.core.forms.widgets.SmallTextarea | nautobot.apps.forms.SmallTextarea
nautobot.core.forms.widgets.StaticSelect2 | nautobot.apps.forms.StaticSelect2
nautobot.core.forms.widgets.StaticSelect2Multiple | nautobot.apps.forms.StaticSelect2Multiple
nautobot.core.forms.widgets.TimePicker | nautobot.apps.forms.TimePicker
nautobot.extras.forms.CustomFieldModelBulkEditFormMixin | nautobot.apps.forms.CustomFieldModelBulkEditFormMixin
nautobot.extras.forms.CustomFieldModelCSVForm | nautobot.apps.forms.CustomFieldModelCSVForm
nautobot.extras.forms.CustomFieldModelFormMixin | nautobot.apps.forms.CustomFieldModelFormMixin
nautobot.extras.forms.NautobotBulkEditForm | nautobot.apps.forms.NautobotBulkEditForm
nautobot.extras.forms.NautobotModelForm | nautobot.apps.forms.NautobotModelForm
nautobot.extras.forms.NoteModelBulkEditFormMixin | nautobot.apps.forms.NoteModelBulkEditFormMixin
nautobot.extras.forms.NoteModelFormMixin | nautobot.apps.forms.NoteModelFormMixin
nautobot.extras.forms.RelationshipModelBulkEditFormMixin | nautobot.apps.forms.RelationshipModelBulkEditFormMixin
nautobot.extras.forms.RelationshipModelFormMixin | nautobot.apps.forms.RelationshipModelFormMixin
nautobot.extras.forms.StatusModelBulkEditFormMixin | nautobot.apps.forms.StatusModelBulkEditFormMixin
nautobot.extras.forms.TagsBulkEditFormMixin | nautobot.apps.forms.TagsBulkEditFormMixin
nautobot.extras.forms.base.NautobotFilterForm | nautobot.apps.forms.NautobotFilterForm
nautobot.extras.forms.forms.get_git_datasource_content_choices | nautobot.apps.forms.get_git_datasource_content_choices
nautobot.extras.forms.forms.provider_choices | nautobot.apps.forms.provider_choices
nautobot.extras.forms.forms.provider_choices_with_blank | nautobot.apps.forms.provider_choices_with_blank
nautobot.extras.forms.mixins.CustomFieldModelFilterFormMixin | nautobot.apps.forms.CustomFieldModelFilterFormMixin
nautobot.extras.forms.mixins.NoteFormBase | nautobot.apps.forms.NoteFormBase
nautobot.extras.forms.mixins.RelationshipModelFilterFormMixin | nautobot.apps.forms.RelationshipModelFilterFormMixin
nautobot.extras.forms.mixins.RoleModelBulkEditFormMixin | nautobot.apps.forms.RoleModelBulkEditFormMixin
nautobot.extras.forms.mixins.RoleModelFilterFormMixin | nautobot.apps.forms.RoleModelFilterFormMixin
nautobot.extras.forms.mixins.StatusModelFilterFormMixin | nautobot.apps.forms.StatusModelFilterFormMixin
nautobot.ipam.formfields.IPAddressFormField | nautobot.apps.forms.IPAddressFormField
nautobot.ipam.formfields.IPNetworkFormField | nautobot.apps.forms.IPNetworkFormField
nautobot.core.graphql.BigInteger | nautobot.apps.graphql.BigInteger
nautobot.core.graphql.execute_query | nautobot.apps.graphql.execute_query
nautobot.core.graphql.execute_saved_query | nautobot.apps.graphql.execute_saved_query
nautobot.core.graphql.types.ContentTypeType | nautobot.apps.graphql.ContentTypeType
nautobot.core.graphql.types.OptimizedNautobotObjectType | nautobot.apps.graphql.OptimizedNautobotObjectType
nautobot.core.graphql.utils.construct_resolver | nautobot.apps.graphql.construct_resolver
nautobot.core.graphql.utils.get_filtering_args_from_filterset | nautobot.apps.graphql.get_filtering_args_from_filterset
nautobot.core.graphql.utils.str_to_var_name | nautobot.apps.graphql.str_to_var_name
nautobot.core.celery.register_jobs | nautobot.apps.jobs.register_jobs
nautobot.core.celery.encoders.NautobotKombuJSONEncoder | nautobot.apps.jobs.NautobotKombuJSONEncoder
nautobot.core.jobs.GitRepositoryDryRun | nautobot.apps.jobs.GitRepositoryDryRun
nautobot.core.jobs.GitRepositorySync | nautobot.apps.jobs.GitRepositorySync
nautobot.extras.jobs.BaseJob | nautobot.apps.jobs.BaseJob
nautobot.extras.jobs.BooleanVar | nautobot.apps.jobs.BooleanVar
nautobot.extras.jobs.ChoiceVar | nautobot.apps.jobs.ChoiceVar
nautobot.extras.jobs.DatabaseFileField | nautobot.apps.jobs.DatabaseFileField
nautobot.extras.jobs.DryRunVar | nautobot.apps.jobs.DryRunVar
nautobot.extras.jobs.enqueue_job_hooks | nautobot.apps.jobs.enqueue_job_hooks
nautobot.extras.jobs.FileVar | nautobot.apps.jobs.FileVar
nautobot.extras.jobs.get_job | nautobot.apps.jobs.get_job
nautobot.extras.jobs.IntegerVar | nautobot.apps.jobs.IntegerVar
nautobot.extras.jobs.IPAddressVar | nautobot.apps.jobs.IPAddressVar
nautobot.extras.jobs.IPAddressWithMaskVar | nautobot.apps.jobs.IPAddressWithMaskVar
nautobot.extras.jobs.IPNetworkVar | nautobot.apps.jobs.IPNetworkVar
nautobot.extras.jobs.is_job | nautobot.apps.jobs.is_job
nautobot.extras.jobs.is_variable | nautobot.apps.jobs.is_variable
nautobot.extras.jobs.Job | nautobot.apps.jobs.Job
nautobot.extras.jobs.JobButtonReceiver | nautobot.apps.jobs.JobButtonReceiver
nautobot.extras.jobs.JobHookReceiver | nautobot.apps.jobs.JobHookReceiver
nautobot.extras.jobs.JSONVar | nautobot.apps.jobs.JSONVar
nautobot.extras.jobs.MultiChoiceVar | nautobot.apps.jobs.MultiChoiceVar
nautobot.extras.jobs.MultiObjectVar | nautobot.apps.jobs.MultiObjectVar
nautobot.extras.jobs.ObjectVar | nautobot.apps.jobs.ObjectVar
nautobot.extras.jobs.RunJobTaskFailed | nautobot.apps.jobs.RunJobTaskFailed
nautobot.extras.jobs.ScriptVariable | nautobot.apps.jobs.ScriptVariable
nautobot.extras.jobs.StringVar | nautobot.apps.jobs.StringVar
nautobot.extras.jobs.TextVar | nautobot.apps.jobs.TextVar
nautobot.core.models.BaseModel | nautobot.apps.models.BaseModel
nautobot.core.models.fields.AttributeSetter | nautobot.apps.models.AttributeSetter
nautobot.core.models.fields.AutoSlugField | nautobot.apps.models.AutoSlugField
nautobot.core.models.fields.ColorField | nautobot.apps.models.ColorField
nautobot.core.models.fields.ForeignKeyLimitedByContentTypes | nautobot.apps.models.ForeignKeyLimitedByContentTypes
nautobot.core.models.fields.ForeignKeyWithAutoRelatedName | nautobot.apps.models.ForeignKeyWithAutoRelatedName
nautobot.core.models.fields.JSONArrayField | nautobot.apps.models.JSONArrayField
nautobot.core.models.fields.mac_unix_expanded_uppercase | nautobot.apps.models.mac_unix_expanded_uppercase
nautobot.core.models.fields.MACAddressCharField | nautobot.apps.models.MACAddressCharField
nautobot.core.models.fields.NaturalOrderingField | nautobot.apps.models.NaturalOrderingField
nautobot.core.models.fields.slugify_dashes_to_underscores | nautobot.apps.models.slugify_dashes_to_underscores
nautobot.core.models.fields.slugify_dots_to_dashes | nautobot.apps.models.slugify_dots_to_dashes
nautobot.core.models.fields.TagsField | nautobot.apps.models.TagsField
nautobot.core.models.generics.OrganizationalModel | nautobot.apps.models.OrganizationalModel
nautobot.core.models.generics.PrimaryModel | nautobot.apps.models.PrimaryModel
nautobot.core.models.managers.BaseManager | nautobot.apps.models.BaseManager
nautobot.core.models.managers.TagsManager | nautobot.apps.models.TagsManager
nautobot.core.models.name_color_content_types.ContentTypeRelatedQuerySet | nautobot.apps.models.ContentTypeRelatedQuerySet
nautobot.core.models.name_color_content_types.NameColorContentTypesModel | nautobot.apps.models.NameColorContentTypesModel
nautobot.core.models.ordering.naturalize | nautobot.apps.models.naturalize
nautobot.core.models.ordering.naturalize_interface | nautobot.apps.models.naturalize_interface
nautobot.core.models.query_functions.CollateAsChar | nautobot.apps.models.CollateAsChar
nautobot.core.models.query_functions.EmptyGroupByJSONBAgg | nautobot.apps.models.EmptyGroupByJSONBAgg
nautobot.core.models.query_functions.JSONBAgg | nautobot.apps.models.JSONBAgg
nautobot.core.models.querysets.CompositeKeyQuerySetMixin | nautobot.apps.models.CompositeKeyQuerySetMixin
nautobot.core.models.querysets.count_related | nautobot.apps.models.count_related
nautobot.core.models.querysets.RestrictedQuerySet | nautobot.apps.models.RestrictedQuerySet
nautobot.core.models.tree_queries.TreeManager | nautobot.apps.models.TreeManager
nautobot.core.models.tree_queries.TreeModel | nautobot.apps.models.TreeModel
nautobot.core.models.tree_queries.TreeQuerySet | nautobot.apps.models.TreeQuerySet
nautobot.core.models.utils.array_to_string | nautobot.apps.models.array_to_string
nautobot.core.models.utils.construct_composite_key | nautobot.apps.models.construct_composite_key
nautobot.core.models.utils.construct_natural_slug | nautobot.apps.models.construct_natural_slug
nautobot.core.models.utils.deconstruct_composite_key | nautobot.apps.models.deconstruct_composite_key
nautobot.core.models.utils.find_models_with_matching_fields | nautobot.apps.models.find_models_with_matching_fields
nautobot.core.models.utils.get_all_concrete_models | nautobot.apps.models.get_all_concrete_models
nautobot.core.models.utils.is_taggable | nautobot.apps.models.is_taggable
nautobot.core.models.utils.pretty_print_query | nautobot.apps.models.pretty_print_query
nautobot.core.models.utils.serialize_object | nautobot.apps.models.serialize_object
nautobot.core.models.utils.serialize_object_v2 | nautobot.apps.models.serialize_object_v2
nautobot.core.models.validators.EnhancedURLValidator | nautobot.apps.models.EnhancedURLValidator
nautobot.core.models.validators.ExclusionValidator | nautobot.apps.models.ExclusionValidator
nautobot.core.models.validators.ValidRegexValidator | nautobot.apps.models.ValidRegexValidator
nautobot.extras.models.ChangeLoggedModel | nautobot.apps.models.ChangeLoggedModel
nautobot.extras.models.ConfigContextModel | nautobot.apps.models.ConfigContextModel
nautobot.extras.models.CustomFieldModel | nautobot.apps.models.CustomFieldModel
nautobot.extras.models.RelationshipModel | nautobot.apps.models.RelationshipModel
nautobot.extras.models.StatusField | nautobot.apps.models.StatusField
nautobot.extras.models.StatusModel | nautobot.apps.models.StatusModel
nautobot.extras.models.mixins.DynamicGroupMixin | nautobot.apps.models.DynamicGroupMixin
nautobot.extras.models.mixins.NotesMixin | nautobot.apps.models.NotesMixin
nautobot.extras.models.models.ConfigContextSchemaValidationMixin | nautobot.apps.models.ConfigContextSchemaValidationMixin
nautobot.extras.plugins.CustomValidator | nautobot.apps.models.CustomValidator
nautobot.extras.utils.extras_features | nautobot.apps.models.extras_features
nautobot.ipam.fields.VarbinaryIPField | nautobot.apps.models.VarbinaryIPField
nautobot.ipam.models.get_default_namespace | nautobot.apps.models.get_default_namespace
nautobot.ipam.models.get_default_namespace_pk | nautobot.apps.models.get_default_namespace_pk
nautobot.extras.querysets.ConfigContextModelQuerySet | nautobot.apps.querysets.ConfigContextModelQuerySet
nautobot.extras.secrets.SecretsProvider | nautobot.apps.secrets.SecretsProvider
nautobot.core.tables.BaseTable | nautobot.apps.tables.BaseTable
nautobot.core.tables.BooleanColumn | nautobot.apps.tables.BooleanColumn
nautobot.core.tables.ButtonsColumn | nautobot.apps.tables.ButtonsColumn
nautobot.core.tables.ChoiceFieldColumn | nautobot.apps.tables.ChoiceFieldColumn
nautobot.core.tables.ColorColumn | nautobot.apps.tables.ColorColumn
nautobot.core.tables.ColoredLabelColumn | nautobot.apps.tables.ColoredLabelColumn
nautobot.core.tables.ComputedFieldColumn | nautobot.apps.tables.ComputedFieldColumn
nautobot.core.tables.ContentTypesColumn | nautobot.apps.tables.ContentTypesColumn
nautobot.core.tables.CustomFieldColumn | nautobot.apps.tables.CustomFieldColumn
nautobot.core.tables.LinkedCountColumn | nautobot.apps.tables.LinkedCountColumn
nautobot.core.tables.RelationshipColumn | nautobot.apps.tables.RelationshipColumn
nautobot.core.tables.TagColumn | nautobot.apps.tables.TagColumn
nautobot.core.tables.ToggleColumn | nautobot.apps.tables.ToggleColumn
nautobot.extras.tables.RoleTableMixin | nautobot.apps.tables.RoleTableMixin
nautobot.extras.tables.StatusTableMixin | nautobot.apps.tables.StatusTableMixin
nautobot.core.testing.create_job_result_and_run_job | nautobot.apps.testing.create_job_result_and_run_job
nautobot.core.testing.get_job_class_and_model | nautobot.apps.testing.get_job_class_and_model
nautobot.core.testing.run_job_for_testing | nautobot.apps.testing.run_job_for_testing
nautobot.core.testing.TransactionTestCase | nautobot.apps.testing.TransactionTestCase
nautobot.core.testing.api.APITestCase | nautobot.apps.testing.APITestCase
nautobot.core.testing.api.APITransactionTestCase | nautobot.apps.testing.APITransactionTestCase
nautobot.core.testing.api.APIViewTestCases | nautobot.apps.testing.APIViewTestCases
nautobot.core.testing.filters.FilterTestCases | nautobot.apps.testing.FilterTestCases
nautobot.core.testing.integration.SeleniumTestCase | nautobot.apps.testing.SeleniumTestCase
nautobot.core.testing.migrations.NautobotDataMigrationTest | nautobot.apps.testing.NautobotDataMigrationTest
nautobot.core.testing.mixins.NautobotTestCaseMixin | nautobot.apps.testing.NautobotTestCaseMixin
nautobot.core.testing.mixins.NautobotTestClient | nautobot.apps.testing.NautobotTestClient
nautobot.core.testing.models.ModelTestCases | nautobot.apps.testing.ModelTestCases
nautobot.core.testing.schema.OpenAPISchemaTestCases | nautobot.apps.testing.OpenAPISchemaTestCases
nautobot.core.testing.utils.create_test_user | nautobot.apps.testing.create_test_user
nautobot.core.testing.utils.disable_warnings | nautobot.apps.testing.disable_warnings
nautobot.core.testing.utils.extract_form_failures | nautobot.apps.testing.extract_form_failures
nautobot.core.testing.utils.extract_page_body | nautobot.apps.testing.extract_page_body
nautobot.core.testing.utils.generate_random_device_asset_tag_of_specified_size | nautobot.apps.testing.generate_random_device_asset_tag_of_specified_size
nautobot.core.testing.utils.get_deletable_objects | nautobot.apps.testing.get_deletable_objects
nautobot.core.testing.utils.post_data | nautobot.apps.testing.post_data
nautobot.core.testing.views.ModelTestCase | nautobot.apps.testing.ModelTestCase
nautobot.core.testing.views.ModelViewTestCase | nautobot.apps.testing.ModelViewTestCase
nautobot.core.testing.views.TestCase | nautobot.apps.testing.TestCase
nautobot.core.testing.views.ViewTestCases | nautobot.apps.testing.ViewTestCases
nautobot.core.apps.HomePageBase | nautobot.apps.ui.HomePageBase
nautobot.core.apps.HomePageGroup | nautobot.apps.ui.HomePageGroup
nautobot.core.apps.HomePageItem | nautobot.apps.ui.HomePageItem
nautobot.core.apps.HomePagePanel | nautobot.apps.ui.HomePagePanel
nautobot.core.apps.NavMenuAddButton | nautobot.apps.ui.NavMenuAddButton
nautobot.core.apps.NavMenuBase | nautobot.apps.ui.NavMenuBase
nautobot.core.apps.NavMenuButton | nautobot.apps.ui.NavMenuButton
nautobot.core.apps.NavMenuGroup | nautobot.apps.ui.NavMenuGroup
nautobot.core.apps.NavMenuImportButton | nautobot.apps.ui.NavMenuImportButton
nautobot.core.apps.NavMenuItem | nautobot.apps.ui.NavMenuItem
nautobot.core.apps.NavMenuTab | nautobot.apps.ui.NavMenuTab
nautobot.core.apps.PermissionsMixin | nautobot.apps.ui.PermissionsMixin
nautobot.core.choices.ButtonColorChoices | nautobot.apps.ui.ButtonColorChoices
nautobot.extras.choices.BannerClassChoices | nautobot.apps.ui.BannerClassChoices
nautobot.extras.plugins.Banner | nautobot.apps.ui.Banner
nautobot.extras.plugins.TemplateExtension | nautobot.apps.ui.TemplateExtension
nautobot.core.views.routers.NautobotUIViewSetRouter | nautobot.apps.urls.NautobotUIViewSetRouter
nautobot.core.releases.get_latest_release | nautobot.apps.utils.get_latest_release
nautobot.core.utils.color.foreground_color | nautobot.apps.utils.foreground_color
nautobot.core.utils.color.hex_to_rgb | nautobot.apps.utils.hex_to_rgb
nautobot.core.utils.color.lighten_color | nautobot.apps.utils.lighten_color
nautobot.core.utils.color.rgb_to_hex | nautobot.apps.utils.rgb_to_hex
nautobot.core.utils.config.get_settings_or_config | nautobot.apps.utils.get_settings_or_config
nautobot.core.utils.data.deepmerge | nautobot.apps.utils.deepmerge
nautobot.core.utils.data.flatten_dict | nautobot.apps.utils.flatten_dict
nautobot.core.utils.data.flatten_iterable | nautobot.apps.utils.flatten_iterable
nautobot.core.utils.data.is_url | nautobot.apps.utils.is_url
nautobot.core.utils.data.is_uuid | nautobot.apps.utils.is_uuid
nautobot.core.utils.data.merge_dicts_without_collision | nautobot.apps.utils.merge_dicts_without_collision
nautobot.core.utils.data.render_jinja2 | nautobot.apps.utils.render_jinja2
nautobot.core.utils.data.shallow_compare_dict | nautobot.apps.utils.shallow_compare_dict
nautobot.core.utils.data.to_meters | nautobot.apps.utils.to_meters
nautobot.core.utils.deprecation.class_deprecated | nautobot.apps.utils.class_deprecated
nautobot.core.utils.deprecation.class_deprecated_in_favor_of | nautobot.apps.utils.class_deprecated_in_favor_of
nautobot.core.utils.filtering.build_lookup_label | nautobot.apps.utils.build_lookup_label
nautobot.core.utils.filtering.get_all_lookup_expr_for_field | nautobot.apps.utils.get_all_lookup_expr_for_field
nautobot.core.utils.filtering.get_filter_field_label | nautobot.apps.utils.get_filter_field_label
nautobot.core.utils.filtering.get_filterset_field | nautobot.apps.utils.get_filterset_field
nautobot.core.utils.filtering.get_filterset_parameter_form_field | nautobot.apps.utils.get_filterset_parameter_form_field
nautobot.core.utils.git.BranchDoesNotExist | nautobot.apps.utils.BranchDoesNotExist
nautobot.core.utils.git.convert_git_diff_log_to_list | nautobot.apps.utils.convert_git_diff_log_to_list
nautobot.core.utils.git.GitRepo | nautobot.apps.utils.GitRepo
nautobot.core.utils.git.swap_status_initials | nautobot.apps.utils.swap_status_initials
nautobot.core.utils.logging.sanitize | nautobot.apps.utils.sanitize
nautobot.core.utils.lookup.get_changes_for_model | nautobot.apps.utils.get_changes_for_model
nautobot.core.utils.lookup.get_filterset_for_model | nautobot.apps.utils.get_filterset_for_model
nautobot.core.utils.lookup.get_form_for_model | nautobot.apps.utils.get_form_for_model
nautobot.core.utils.lookup.get_model_from_name | nautobot.apps.utils.get_model_from_name
nautobot.core.utils.lookup.get_related_class_for_model | nautobot.apps.utils.get_related_class_for_model
nautobot.core.utils.lookup.get_route_for_model | nautobot.apps.utils.get_route_for_model
nautobot.core.utils.lookup.get_table_for_model | nautobot.apps.utils.get_table_for_model
nautobot.core.utils.permissions.get_permission_for_model | nautobot.apps.utils.get_permission_for_model
nautobot.core.utils.permissions.permission_is_exempt | nautobot.apps.utils.permission_is_exempt
nautobot.core.utils.permissions.resolve_permission | nautobot.apps.utils.resolve_permission
nautobot.core.utils.permissions.resolve_permission_ct | nautobot.apps.utils.resolve_permission_ct
nautobot.core.utils.requests.convert_querydict_to_factory_formset_acceptable_querydict | nautobot.apps.utils.convert_querydict_to_factory_formset_acceptable_querydict
nautobot.core.utils.requests.ensure_content_type_and_field_name_in_query_params | nautobot.apps.utils.ensure_content_type_and_field_name_in_query_params
nautobot.core.utils.requests.get_filterable_params_from_filter_params | nautobot.apps.utils.get_filterable_params_from_filter_params
nautobot.core.utils.requests.is_single_choice_field | nautobot.apps.utils.is_single_choice_field
nautobot.core.utils.requests.normalize_querydict | nautobot.apps.utils.normalize_querydict
nautobot.extras.plugins.validators.custom_validator_clean | nautobot.apps.utils.custom_validator_clean
nautobot.extras.plugins.validators.wrap_model_clean_methods | nautobot.apps.utils.wrap_model_clean_methods
nautobot.extras.utils.ChangeLoggedModelsQuery | nautobot.apps.utils.ChangeLoggedModelsQuery
nautobot.extras.utils.check_if_key_is_graphql_safe | nautobot.apps.utils.check_if_key_is_graphql_safe
nautobot.extras.utils.FeaturedQueryMixin | nautobot.apps.utils.FeaturedQueryMixin
nautobot.extras.utils.FeatureQuery | nautobot.apps.utils.FeatureQuery
nautobot.extras.utils.fixup_null_statuses | nautobot.apps.utils.fixup_null_statuses
nautobot.extras.utils.generate_signature | nautobot.apps.utils.generate_signature
nautobot.extras.utils.get_base_template | nautobot.apps.utils.get_base_template
nautobot.extras.utils.get_celery_queues | nautobot.apps.utils.get_celery_queues
nautobot.extras.utils.get_worker_count | nautobot.apps.utils.get_worker_count
nautobot.extras.utils.image_upload | nautobot.apps.utils.image_upload
nautobot.extras.utils.migrate_role_data | nautobot.apps.utils.migrate_role_data
nautobot.extras.utils.populate_model_features_registry | nautobot.apps.utils.populate_model_features_registry
nautobot.extras.utils.refresh_job_model_from_job_class | nautobot.apps.utils.refresh_job_model_from_job_class
nautobot.extras.utils.remove_prefix_from_cf_key | nautobot.apps.utils.remove_prefix_from_cf_key
nautobot.extras.utils.RoleModelsQuery | nautobot.apps.utils.RoleModelsQuery
nautobot.extras.utils.TaggableClassesQuery | nautobot.apps.utils.TaggableClassesQuery
nautobot.extras.utils.task_queues_as_choices | nautobot.apps.utils.task_queues_as_choices
nautobot.core.views.generic.BulkComponentCreateView | nautobot.apps.views.BulkComponentCreateView
nautobot.core.views.generic.BulkCreateView | nautobot.apps.views.BulkCreateView
nautobot.core.views.generic.BulkDeleteView | nautobot.apps.views.BulkDeleteView
nautobot.core.views.generic.BulkEditView | nautobot.apps.views.BulkEditView
nautobot.core.views.generic.BulkImportView | nautobot.apps.views.BulkImportView
nautobot.core.views.generic.BulkRenameView | nautobot.apps.views.BulkRenameView
nautobot.core.views.generic.ComponentCreateView | nautobot.apps.views.ComponentCreateView
nautobot.core.views.generic.ObjectDeleteView | nautobot.apps.views.ObjectDeleteView
nautobot.core.views.generic.ObjectEditView | nautobot.apps.views.ObjectEditView
nautobot.core.views.generic.ObjectImportView | nautobot.apps.views.ObjectImportView
nautobot.core.views.generic.ObjectListView | nautobot.apps.views.ObjectListView
nautobot.core.views.generic.ObjectView | nautobot.apps.views.ObjectView
nautobot.core.views.mixins.AdminRequiredMixin | nautobot.apps.views.AdminRequiredMixin
nautobot.core.views.mixins.ContentTypePermissionRequiredMixin | nautobot.apps.views.ContentTypePermissionRequiredMixin
nautobot.core.views.mixins.GetReturnURLMixin | nautobot.apps.views.GetReturnURLMixin
nautobot.core.views.mixins.NautobotViewSetMixin | nautobot.apps.views.NautobotViewSetMixin
nautobot.core.views.mixins.ObjectBulkCreateViewMixin | nautobot.apps.views.ObjectBulkCreateViewMixin
nautobot.core.views.mixins.ObjectBulkDestroyViewMixin | nautobot.apps.views.ObjectBulkDestroyViewMixin
nautobot.core.views.mixins.ObjectBulkUpdateViewMixin | nautobot.apps.views.ObjectBulkUpdateViewMixin
nautobot.core.views.mixins.ObjectChangeLogViewMixin | nautobot.apps.views.ObjectChangeLogViewMixin
nautobot.core.views.mixins.ObjectDestroyViewMixin | nautobot.apps.views.ObjectDestroyViewMixin
nautobot.core.views.mixins.ObjectDetailViewMixin | nautobot.apps.views.ObjectDetailViewMixin
nautobot.core.views.mixins.ObjectEditViewMixin | nautobot.apps.views.ObjectEditViewMixin
nautobot.core.views.mixins.ObjectListViewMixin | nautobot.apps.views.ObjectListViewMixin
nautobot.core.views.mixins.ObjectNotesViewMixin | nautobot.apps.views.ObjectNotesViewMixin
nautobot.core.views.mixins.ObjectPermissionRequiredMixin | nautobot.apps.views.ObjectPermissionRequiredMixin
nautobot.core.views.paginator.EnhancedPage | nautobot.apps.views.EnhancedPage
nautobot.core.views.paginator.EnhancedPaginator | nautobot.apps.views.EnhancedPaginator
nautobot.core.views.paginator.get_paginate_count | nautobot.apps.views.get_paginate_count
nautobot.core.views.renderers.NautobotHTMLRenderer | nautobot.apps.views.NautobotHTMLRenderer
nautobot.core.views.utils.check_filter_for_display | nautobot.apps.views.check_filter_for_display
nautobot.core.views.utils.csv_format | nautobot.apps.views.csv_format
nautobot.core.views.utils.get_csv_form_fields_from_serializer_class | nautobot.apps.views.get_csv_form_fields_from_serializer_class
nautobot.core.views.utils.handle_protectederror | nautobot.apps.views.handle_protectederror
nautobot.core.views.utils.prepare_cloned_fields | nautobot.apps.views.prepare_cloned_fields
nautobot.core.views.viewsets.NautobotUIViewSet | nautobot.apps.views.NautobotUIViewSet
nautobot.extras.views.check_and_call_git_repository_function | nautobot.apps.views.check_and_call_git_repository_function
nautobot.extras.views.ObjectDynamicGroupsView | nautobot.apps.views.ObjectDynamicGroupsView
nautobot.extras.views.ObjectNotesView | nautobot.apps.views.ObjectNotesView

## Replace PluginMenuItem with NavMenuItem

In your app's `navigation.py` file. If you are still using `PluginMenuItem` from `nautobot.extras.plugin`, you should replace those code with `NavMenuGroup`, `NavMenuItem`, and `NavMenuTab` from `nautobot.apps.ui`.

For example:

Before:

        from nautobot.extras.plugins import PluginMenuItem

        menu_items = (
            PluginMenuItem(
                link="plugins:your_app:dashboard",
                link_text="Dashboard",
                permissions=["your_app.view_sync"],
            ),
            PluginMenuItem(
                link="plugins:your_app:sync_list",
                link_text="History",
                permissions=["your_app.view_sync"],
            ),
            PluginMenuItem(
                link="plugins:your_app:synclogentry_list",
                link_text="Logs",
                permissions=["your_app.view_synclogentry"],
            ),
        )

After:

    from nautobot.apps.ui import NavMenuGroup, NavMenuItem, NavMenuTab

    items = [
        NavMenuItem(
            link="plugins:your_app:dashboard",
            name="Dashboard",
            permissions=["your_app.view_sync"],
        ),
        NavMenuItem(
            link="plugins:your_app:sync_list",
            name="History",
            permissions=["your_app.view_sync"],
        ),
        NavMenuItem(
            link="plugins:your_app:synclogentry_list",
            name="Logs",
            permissions=["your_app.view_synclogentry"],
        ),
    ]

    menu_items = (
        NavMenuTab(
            name="Apps",
            groups=(NavMenuGroup(weight=1000, name="Your App", items=tuple(items)),),
        ),
    )

### Remove Tag/Tags Filter from FilterSet Definitions

In Nautobot 2.0, you can safely remove `tag = TagFilter(...)` from your filter set definitions as long as your filter sets inherit from `NautobotFilterSet` class and `tags` is added to the filter set class `Meta.fields`.

For example, before the filter set could look like this:

    class AppModelFilterSet(BaseFilterSet):

        name = MultiValueCharFilter(...)
        number = MultiValueNumberFilter(...)
        tag = TagFilter(...)

        class Meta:
            fields = ["name", "number"]

After changing the base class to `NautobotFilterSet` the `tag` filter should be removed:

    class AppModelFilterSet(NautobotFilterSet):

        name = MultiValueCharFilter(...)
        number = MultiValueNumberFilter(...)

        class Meta:
            fields = ["name", "number", "tags"]

## Replace DjangoFilterBackend with NautobotFilterBackend

If your REST API has any `FilterBackend` classes derived from `DjangoFilterBackend`, you should replace `DjangoFilterBackend` with `NautobotFilterBackend`.

## App Model Serializer Inheritance

App Model Serializers for any models that could have a Generic Foreign Key or a Many to Many relationship from a Nautobot Core model must inherit from BaseModelSerializer at a minimum so that they have a properly generated `object_type` field. This also applies to the case where your model is a subclass of `ChangeLoggedModel` and you will have a Generic Foreign Key from `ObjectChange`'s `changed_object` field. Otherwise drf-spectacular schema generation will throw an error:

    (drf_spectacular.E001) Schema generation threw exception "Field name `object_type` is not valid for model `YourAppModel`.

## Revamp REST API Serializers

`NestedSerializer` classes are no longer needed in Nautobot 2.0. If any `NestedSerializers` exist for your models, you should just remove their class definitions and references.

After removing existing `NestedSerializers`, you can change the `fields` attribute in your serializers' `class Meta` to `__all__` and that will automatically include all the model's fields in the serializer, including related-model fields that would previously have required a reference to a `NestedSerializer`. If you want to exclude certain fields of the model, you can specify a list of fields you want to display in the `fields` attribute instead.

Warning

Use caution around `fields = "__all__"` -- if your model has any fields that should not be exposed in the REST API, you should avoid using `"__all__"` and instead use an explicit `fields` list to ensure that such fields are not exposed. In some cases, it may be appropriate to use `"__all__"` in combination with flags such as `write_only=True` on specific fields, but proceed with caution and examine the REST API data carefully to ensure that its contents are as expected.

Include all model attributes:

    class ExampleModelSerializer(NautobotModelSerializer):
        """Used for normal CRUD operations."""

        url = serializers.HyperlinkedIdentityField(view_name="plugins-api:example_app-api:anotherexamplemodel-detail")

        class Meta:
            model = AnotherExampleModel
            fields = "__all__"

Include only specified model attributes:

    class ExampleModelSerializer(NautobotModelSerializer):
        """Used for normal CRUD operations."""

        url = serializers.HyperlinkedIdentityField(view_name="plugins-api:example_app-api:anotherexamplemodel-detail")

        class Meta:
            model = AnotherExampleModel
            # example_attribute_4 is not included in the serializer
            fields = ["url", "example_attribute_1", "example_attribute_2", "example_attribute_3"]

In addition, the `?brief=` API query parameter is replaced by `?depth=<0-10>`. As a result, the ability to specify `brief_mode` in `DynamicModelChoiceField`, `DynamicModelMultipleChoiceField`, and `MultiMatchModelMultipleChoiceField` has also been removed. For every occurrence of the aforementioned fields where you have `brief_mode` set to `True/False` (e.g. `brief_mode=True`), please remove the statement, leaving other occurrences of the fields where you do not have `brief_mode` specified as they are. Check out our API documentation for this change.

## Revamp CSV Import and Export

CSV Import for models are now done automatically via the REST API. As a result of this change, `CSVForm` classes are no longer needed and should be deleted. In addition, the Model `csv_headers` attribute and `to_csv` method are no longer needed or used in CSV generation, and should be removed from your model definitions. Check out our release notes for this specific change.

## Deprecated Templates

Over time, some templates have been deprecated and either consolidated or replaced with new ones. If you are using a deprecated template, you should migrate to the new template. We have included a script to help migrate all html files that extend a deprecated template to the new template. You can run it with the following command:

    nautobot-migrate-deprecated-templates <path-to-your-app> [--dry-run]

This will recursively find all `.html` files in the given path and replace extends references (`{% extends 'path/to/deprecated_template.html' %}`) to deprecated templates with the replacement ones. You can also run it with the `--dry-run` flag to see what changes would be made without actually making any changes.

For a list of deprecated templates and their replacements, see the following table:

Full table of deprecated templates and their replacements

Deprecated Template | Replacement Template
--- | ---
circuits/circuit.html | generic/object_retrieve.html
circuits/circuit_edit.html | circuits/circuit_create.html
circuits/circuit_retrieve.html | generic/object_retrieve.html
circuits/circuit_update.html | circuits/circuit_create.html
circuits/circuittermination.html | generic/object_retrieve.html
circuits/circuittermination_edit.html | circuits/circuittermination_create.html
circuits/circuittermination_retrieve.html | generic/object_retrieve.html
circuits/circuittermination_update.html | circuits/circuittermination_create.html
circuits/circuittype.html | generic/object_retrieve.html
circuits/circuittype_retrieve.html | generic/object_retrieve.html
circuits/provider.html | generic/object_retrieve.html
circuits/provider_edit.html | circuits/provider_create.html
circuits/provider_retrieve.html | generic/object_retrieve.html
circuits/provider_update.html | circuits/provider_create.html
circuits/providernetwork.html | generic/object_retrieve.html
circuits/providernetwork_retrieve.html | generic/object_retrieve.html
cloud/cloudaccount_retrieve.html | generic/object_retrieve.html
cloud/cloudnetwork_retrieve.html | generic/object_retrieve.html
cloud/cloudresourcetype_retrieve.html | generic/object_retrieve.html
cloud/cloudservice_retrieve.html | generic/object_retrieve.html
dcim/cable.html | dcim/cable_retrieve.html
dcim/cable_edit.html | dcim/cable_update.html
dcim/controller/base.html | generic/object_retrieve.html
dcim/controller_retrieve.html | generic/object_retrieve.html
dcim/controller_wirelessnetworks.html | generic/object_retrieve.html
dcim/controllermanageddevicegroup_retrieve.html | generic/object_retrieve.html
dcim/device/base.html | generic/object_retrieve.html
dcim/device/consoleports.html | generic/object_retrieve.html
dcim/device/consoleserverports.html | generic/object_retrieve.html
dcim/device/devicebays.html | generic/object_retrieve.html
dcim/device/frontports.html | generic/object_retrieve.html
dcim/device/interfaces.html | generic/object_retrieve.html
dcim/device/inventory.html | generic/object_retrieve.html
dcim/device/modulebays.html | generic/object_retrieve.html
dcim/device/poweroutlets.html | generic/object_retrieve.html
dcim/device/powerports.html | generic/object_retrieve.html
dcim/device/rearports.html | generic/object_retrieve.html
dcim/device/wireless.html | generic/object_retrieve.html
dcim/device_component.html | generic/object_retrieve.html
dcim/device_edit.html | dcim/device_create.html
dcim/devicefamily_retrieve.html | generic/object_retrieve.html
dcim/deviceredundancygroup_retrieve.html | generic/object_retrieve.html
dcim/devicetype.html | generic/object_retrieve.html
dcim/devicetype_edit.html | dcim/devicetype_update.html
dcim/devicetype_retrieve.html | generic/object_retrieve.html
dcim/interfaceredundancygroup_retrieve.html | generic/object_retrieve.html
dcim/location.html | generic/object_retrieve.html
dcim/location_edit.html | dcim/location_update.html
dcim/location_retrieve.html | generic/object_retrieve.html
dcim/locationtype.html | generic/object_retrieve.html
dcim/locationtype_retrieve.html | generic/object_retrieve.html
dcim/manufacturer.html | generic/object_retrieve.html
dcim/modulebay_retrieve.html | generic/object_retrieve.html
dcim/platform.html | generic/object_retrieve.html
dcim/powerfeed.html | generic/object_retrieve.html
dcim/powerfeed_retrieve.html | generic/object_retrieve.html
dcim/powerpanel.html | generic/object_retrieve.html
dcim/powerpanel_edit.html | generic/object_create.html
dcim/powerpanel_retrieve.html | generic/object_retrieve.html
dcim/rack.html | dcim/rack_retrieve.html
dcim/rack_edit.html | dcim/rack_update.html
dcim/rackgroup.html | generic/object_retrieve.html
dcim/rackreservation.html | dcim/rackreservation_retrieve.html
dcim/softwareimagefile_retrieve.html | generic/object_retrieve.html
dcim/softwareversion_retrieve.html | generic/object_retrieve.html
dcim/virtualchassis.html | generic/object_retrieve.html
dcim/virtualchassis_add.html | dcim/virtualchassis_create.html
dcim/virtualchassis_edit.html | virtualchassis_update.html
dcim/virtualchassis_retrieve.html | generic/object_retrieve.html
dcim/virtualdevicecontext_retrieve.html | generic/object_retrieve.html
extras/computedfield.html | generic/object_retrieve.html
extras/computedfield_retrieve.html | generic/object_retrieve.html
extras/configcontext.html | generic/object_retrieve.html
extras/configcontext_edit.html | extras/configcontext_update.html
extras/configcontext_retrieve.html | generic/object_retrieve.html
extras/configcontextschema.html | extras/configcontextschema_retrieve.html
extras/configcontextschema_edit.html | extras/configcontextschema_update.html
extras/contact_retrieve.html | generic/object_retrieve.html
extras/customfield.html | generic/object_retrieve.html
extras/customfield_edit.html | extras/customfield_update.html
extras/customfield_retrieve.html | generic/object_retrieve.html
extras/customlink.html | generic/object_retrieve.html
extras/dynamicgroup.html | extras/dynamicgroup_retrieve.html
extras/dynamicgroup_edit.html | extras/dynamicgroup_update.html
extras/exporttemplate.html | generic/object_retrieve.html
extras/gitrepository.html | extras/gitrepository_retrieve.html
extras/gitrepository_object_edit.html | extras/gitrepository_update.html
extras/graphqlquery.html | generic/object_retrieve.html
extras/graphqlquery_list.html | generic/object_list.html
extras/graphqlquery_retrieve.html | generic/object_retrieve.html
extras/job_detail.html | generic/object_retrieve.html
extras/jobbutton_retrieve.html | generic/object_retrieve.html
extras/jobhook.html | generic/object_retrieve.html
extras/jobqueue_retrieve.html | generic/object_retrieve.html
extras/jobresult.html | extras/jobresult_retrieve.html
extras/metadatatype_retrieve.html | generic/object_retrieve.html
extras/note.html | generic/object_retrieve.html
extras/note_retrieve.html | generic/object_retrieve.html
extras/object_changelog.html | generic/object_changelog.html
extras/object_notes.html | generic/object_notes.html
extras/objectchange.html | extras/objectchange_retrieve.html
extras/objectchange_list.html | generic/object_list.html
extras/relationship.html | generic/object_retrieve.html
extras/secret.html | generic/object_retrieve.html
extras/secret_edit.html | extras/secret_create.html
extras/secretsgroup.html | generic/object_retrieve.html
extras/secretsgroup_edit.html | extras/secretsgroup_update.html
extras/secretsgroup_retrieve.html | generic/object_retrieve.html
extras/status.html | generic/object_retrieve.html
extras/tag.html | generic/object_retrieve.html
extras/tag_edit.html | extras/tag_update.html
extras/tag_retrieve.html | generic/object_retrieve.html
extras/team_retrieve.html | generic/object_retrieve.html
generic/object_bulk_delete.html | generic/object_bulk_destroy.html
generic/object_bulk_edit.html | generic/object_bulk_update.html
generic/object_bulk_import.html | generic/object_bulk_create.html
generic/object_delete.html | generic/object_destroy.html
generic/object_detail.html | generic/object_retrieve.html
generic/object_edit.html | generic/object_create.html
ipam/namespace_retrieve.html | generic/object_retrieve.html
ipam/prefix.html | generic/object_retrieve.html
ipam/prefix_edit.html | ipam/prefix_create.html
ipam/prefix_retrieve.html | generic/object_retrieve.html
ipam/rir.html | generic/object_retrieve.html
ipam/routetarget.html | generic/object_retrieve.html
ipam/service.html | generic/object_retrieve.html
ipam/service_edit.html | generic/object_create.html
ipam/service_retrieve.html | generic/object_retrieve.html
ipam/vlan.html | generic/object_retrieve.html
ipam/vlan_edit.html | ipam/vlan_update.html
ipam/vlan_retrieve.html | generic/object_retrieve.html
ipam/vlangroup.html | generic/object_retrieve.html
ipam/vrf.html | generic/object_retrieve.html
tenancy/tenant.html | generic/object_retrieve.html
tenancy/tenant_edit.html | tenancy/tenant_create.html
tenancy/tenantgroup.html | generic/object_retrieve.html
tenancy/tenantgroup_retrieve.html | generic/object_retrieve.html
virtualization/clustergroup.html | generic/object_retrieve.html
virtualization/clustertype.html | generic/object_retrieve.html
virtualization/virtualmachine.html | generic/object_retrieve.html
virtualization/virtualmachine_edit.html | virtualization/virtualmachine_update.html
virtualization/virtualmachine_retrieve.html | generic/object_retrieve.html
wireless/radioprofile_retrieve.html | generic/object_retrieve.html
wireless/supporteddatarate_retrieve.html | generic/object_retrieve.html
wireless/wirelessnetwork_retrieve.html | generic/object_retrieve.html